<?php

namespace SM\Controller;

use SM\Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SM\Service\Sm00011000ApuracaoFaturamentoService;
use SM\Traits\TResponse;

class Sm00011000ApuracaoFaturamentoController
{
    use TResponse;

    protected $apuracaoFaturamentoService;

    public function __construct(Sm00011000ApuracaoFaturamentoService $apuracaoFaturamentoService)
    {
        $this->apuracaoFaturamentoService = $apuracaoFaturamentoService;
    }

    public function getApuracaoFaturamento()
    {
        try {
            $dynamicFilter = null;
            if (!empty($_REQUEST['dynamic_filter'])) {
                $dynamicFilter = Utilities::decodificarDynamicFilter($_REQUEST['dynamic_filter']);
            }
            $data = $this->apuracaoFaturamentoService->getApuracaoFaturamento($dynamicFilter);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFilialFatura()
    {
        try {
            $data = $this->apuracaoFaturamentoService->getFilialFatura();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getNrNotaFiscal(Request $request)
    {
        try {
            $data = $this->apuracaoFaturamentoService->getNrNotaFiscal($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getItensDesmembramento(Request $request)
    {
        try {
            $data = $this->apuracaoFaturamentoService->getItensDesmembramento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabItensApuracaoFaturamento(Request $request)
    {
        try {
            $data = $this->apuracaoFaturamentoService->getTabItensApuracaoFaturamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabDadosAgrupamentos(Request $request)
    {
        try {
            $data = $this->apuracaoFaturamentoService->getTabDadosAgrupamentos($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getModalErroApuracaoFaturamento()
    {
        try {
            $data = $this->apuracaoFaturamentoService->getModalErroApuracaoFaturamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validarAgrupamentoFatMarcados(DTO\Request $request)
    {
        try {
            $contratos = $this->apuracaoFaturamentoService->validarAgrupamentoFatMarcados($request->getParameters());
            $this->sendResponse($contratos, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validarAgrupamentoFat(DTO\Request $request)
    {
        try {
            $resultado = $this->apuracaoFaturamentoService->validarAgrupamentoFat($request->getParameters());
            $this->sendResponse($resultado, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function gerarFaturamentoApuracao(DTO\Request $request)
    {
        try {
            $contratos = $this->apuracaoFaturamentoService->gerarFaturamentoApuracao($request->getParameters());
            $this->sendResponse($contratos, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function cancelarFaturamentoApuracao(DTO\Request $request)
    {
        try {
            $vencimentos = $this->apuracaoFaturamentoService->cancelarFaturamentoApuracao($request->getParameters());
            $this->sendResponse($vencimentos, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function alterarDataSaidaDaNotaFiscal(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->alterarDataSaidaDaNotaFiscal($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function alterarStatusParcelasZeradas(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->alterarStatusParcelasZeradas($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function anularApuracao(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->anularApuracao($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function invoiceValidateHasAlreadyBeenUsed(Request $request)
    {
        try {
            $data = $this->apuracaoFaturamentoService->invoiceValidateHasAlreadyBeenUsed($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function fatuManual(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->fatuManual($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function validaQtItens(DTO\Request $request)
    {
        try {
            $valida = $this->apuracaoFaturamentoService->validaQtItens($request->getParameters());
            $this->sendResponse($valida, 200);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function desmembrarParcela(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->desmembrarParcela($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function desagruparParcelasFaturamento(DTO\Request $request)
    {
        try {
            $this->apuracaoFaturamentoService->desagruparParcelasFaturamento($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

}
