import {
    Http, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, IGridEvent, DialogService, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00057002ConfiguracaoRegionalMoedaController {
    public adicionarConfiguracaoRegionalMoeda() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-moeda');
        const newId = 0;
        grid.addNewRow({ NRMOEDA: newId, IDPADRAO: 'N', IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMMOEDA_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public inserirConfiguracaoRegionalMoeda({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-moeda');
        const moedas = grid.getEditedRows();

        if (Utilities.validateGrid(grid)) {
            LoadingService.show();
            Http.post('/inserirConfiguracaoRegionalMoeda', moedas).then(() => {
                grid.cancelEditedRows();
                grid.reload();
                Utilities.showSuccessMessage();
                grid.datasource.get();
            }).catch((error) => {
                if (error.response.data.error === 'MOEDA EXISTE') {
                    Utilities.alertMessage('Não é possivel adicionar uma moeda existente', 'error');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public dialogDeletarConfiguracaoRegionalMoeda({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Sm00057002ConfiguracaoRegionalMoedaController.deletarConfiguracaoRegionalMoeda');
    }

    public deletarConfiguracaoRegionalMoeda() {
        DialogService.hide();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-moeda');
        LoadingService.show();
        Http.post('/deletarConfiguracaoRegionalMoeda', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
